@@ -2,7 +2,6 @@ import asyncio
 import signal
 import engineio
 
-loop = asyncio.get_event_loop()
 eio = engineio.AsyncClient()
 exit_event = asyncio.Event()
 original_signal_handler = None
@@ -50,4 +49,4 @@ async def start_client():
 
 if __name__ == '__main__':
     original_signal_handler = signal.signal(signal.SIGINT, signal_handler)
-    loop.run_until_complete(start_client())
+    asyncio.run(start_client())
